summaryrefslogtreecommitdiff
path: root/sapi/roxen/roxen.c
diff options
context:
space:
mode:
authorDavid Hedbor <neotron@php.net>2000-03-07 20:20:42 +0000
committerDavid Hedbor <neotron@php.net>2000-03-07 20:20:42 +0000
commit71a4bdc8826843a9cc44824f45ee64c3e6c43a70 (patch)
treed4805ce76feb1aa83fa4990b9cee1c4f00056878 /sapi/roxen/roxen.c
parent77fb7d2b64f61c68dc23cf89e9bdd78c21079106 (diff)
downloadphp-git-71a4bdc8826843a9cc44824f45ee64c3e6c43a70.tar.gz
Changed typo (interpretor->interpreter)
Diffstat (limited to 'sapi/roxen/roxen.c')
-rw-r--r--sapi/roxen/roxen.c12
1 files changed, 6 insertions, 6 deletions
diff --git a/sapi/roxen/roxen.c b/sapi/roxen/roxen.c
index d219031b43..ed374305cb 100644
--- a/sapi/roxen/roxen.c
+++ b/sapi/roxen/roxen.c
@@ -130,7 +130,7 @@ extern int fd_from_object(struct object *o);
static unsigned char roxen_php_initialized;
/* This allows calling of pike functions from the PHP callbacks,
* which requires the Pike interpretor to be locked.
*/
#define THREAD_SAFE_RUN(COMMAND, what) do {\
struct thread_state *state;\
@@ -206,7 +206,7 @@ INLINE static int lookup_integer_header(char *headername, int default_value)
/*
* php_roxen_low_ub_write() writes data to the client connection. Might be
* rewritten to do more direct IO to save CPU and the need to lock the *
* interpretor for better threading.
*/
static int
@@ -636,10 +636,10 @@ void f_php_roxen_request_handler(INT32 args)
if(current_thread == th_self())
error("PHP4.Interpetor->run: Tried to run a PHP-script from a PHP "
"callback!");
- get_all_args("PHP4.Interpretor->run", args, "%S%m%O%*", &script,
+ get_all_args("PHP4.Interpreter->run", args, "%S%m%O%*", &script,
&request_data, &my_fd_obj, &done_callback);
if(done_callback->type != PIKE_T_FUNCTION)
- error("PHP4.Interpretor->run: Bad argument 4, expected function.\n");
+ error("PHP4.Interpreter->run: Bad argument 4, expected function.\n");
PHP_LOCK(THIS); /* Need to lock here or reusing the same object might cause
* problems in changing stuff in that object */
#ifndef ROXEN_USE_ZTS
@@ -669,7 +669,7 @@ void f_php_roxen_request_handler(INT32 args)
{
int fd = fd_from_object(raw_fd->u.object);
if(fd == -1)
- error("PHP4.Interpretor->run: my_fd object not open or not an FD.\n");
+ error("PHP4.Interpreter->run: my_fd object not open or not an FD.\n");
THIS->my_fd = fd;
} else
THIS->my_fd = 0;
@@ -717,7 +717,7 @@ void pike_module_init()
set_init_callback(clear_struct);
pike_add_function("run", f_php_roxen_request_handler,
"function(string,mapping,object,function:int)", 0);
- add_program_constant("Interpretor", (php_program = end_program()), 0);
+ add_program_constant("Interpreter", (php_program = end_program()), 0);
}
/*
@@ -130,7 +130,7 @@ extern int fd_from_object(struct object *o);
static unsigned char roxen_php_initialized;
/* This allows calling of pike functions from the PHP callbacks,
- * which requires the Pike interpretor to be locked.
+ * which requires the Pike interpreter to be locked.
*/
#define THREAD_SAFE_RUN(COMMAND, what) do {\
@@ -206,7 +206,7 @@ INLINE static int lookup_integer_header(char *headername, int default_value)
* php_roxen_low_ub_write() writes data to the client connection. Might be
* rewritten to do more direct IO to save CPU and the need to lock the *
- * interpretor for better threading.
+ * interpreter for better threading.
*/
static int